==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/zh/templates.php <==
<?php
regGS("The template $1 is in use and can not be deleted.", "");
regGS("The folder could not be deleted.", "文件夹不能删除");
regGS("The directory must be empty", "");
regGS("Create new folder", "建新文件夹");
regGS("Upload template", "上载模版");
regGS("Creating new folder", "正在建新文件夹");
regGS("You do not have the right to create new folders.", "您无权产生新文件夹");
regGS("The folder $1 could not be created", "文件夹$1不能创建");
regGS("A file or folder having the name $1 already exists", "");
regGS("You do not have the right to delete templates.", "您无权删除模版");
regGS("Are you sure you want to delete the folder $1 from $2?", "您确定要从$2中删除文件夹$1？");
regGS("Are you sure you want to delete the template $1 from folder $2?", "您确认要从文件夹$2中删除模版$1？");
regGS("Deleting template", "正在删除模版");
regGS("Deleting folder", "正在删除文件夹");
regGS("The folder has been deleted.", "文件夹已被删除");
regGS("The template has been deleted.", "模版已被删除");
regGS("The template could not be deleted.", "模版不能删除");
regGS("Template $1 was deleted", "");
regGS("Delete folder", "删除文件夹");
regGS("Folders", "文件夹");
regGS("No folders.", "无文件夹");
regGS("Files", "文件");
regGS("No templates.", "无模版");
regGS("Uploading template", "正在上载模版");
regGS("File", "文件");
regGS("Create new template", "建立新模版");
regGS("Creating new template", "正在建新模版");
regGS("Duplicate template", "复制模版");
regGS("Edit template", "编辑模版");
regGS("Save", "保存");
regGS("The template $1 has been created.", "模版$1已建立");
regGS("Do you want to edit the template ?", "您要编辑模版？");
regGS("The template $1 could not be created.", "模版$1不能被建立");
regGS("Template $1 was changed", "模版$1被改变");
regGS("New template $1 was created", "新模版$1被建立");
regGS("Template $1 was duplicated into $2", "模版$1被复制到$2");
regGS("Template charset", "模版字符");
regGS("Select a language/character set", "选择语言/字符");
regGS("All languages", "所有语言");
regGS("You do not have the right to modify templates.", "");
regGS("Invalid template file $1", "");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/zh/templates.php <==
<?php 
regGS("Template ID:", "");
regGS("Template ID", "");
regGS("Template $1 no longer exists!", "");
regGS("New template $1 created", "");
regGS("If the file you specified is a text file, you can convert its character set using the dropdown below.", "");
regGS("Directory $1 was deleted", "");
regGS("Directory $1 created.", "");
regGS("You must select a file to upload.", "");
regGS("You can only replace a file with a file of the same type.  The original file is of type \"$1\", and the file you uploaded was of type \"$2\".", "");
regGS("Unable to save the file '$1' to the path '$2'.", "");
regGS("Replace file:", "");
regGS("Replace", "");
regGS("File \"$1\" uploaded.", "");
regGS("File \"$1\" replaced.", "");
regGS("The folder name can't be '..' or '.'", "");
regGS("The template '$1' was saved successfully.", "");
regGS("The template $1 is in use and can not be deleted.", "");
regGS("Create new folder", "建新文件夹");
regGS("Upload template", "上载模版");
regGS("You do not have the right to create new folders.", "您无权产生新文件夹");
regGS("A file or folder having the name $1 already exists", "");
regGS("You do not have the right to delete templates.", "您无权删除模版");
regGS("Are you sure you want to delete the folder $1 from $2?", "您确定要从$2中删除文件夹$1？");
regGS("Are you sure you want to delete the template $1 from folder $2?", "您确认要从文件夹$2中删除模版$1？");
regGS("The folder has been deleted.", "文件夹已被删除");
regGS("The template has been deleted.", "模版已被删除");
regGS("The template could not be deleted.", "模版不能删除");
regGS("Template $1 was deleted", "");
regGS("Delete folder", "删除文件夹");
regGS("Folders", "文件夹");
regGS("No folders.", "无文件夹");
regGS("Files", "文件");
regGS("No templates.", "无模版");
regGS("File", "文件");
regGS("Create new template", "建立新模版");
regGS("Duplicate template", "复制模版");
regGS("Edit template", "编辑模版");
regGS("Save", "保存");
regGS("The template $1 could not be created.", "模版$1不能被建立");
regGS("Template $1 was changed", "模版$1被改变");
regGS("Template $1 was duplicated into $2", "模版$1被复制到$2");
regGS("Template charset", "模版字符");
regGS("Select a language/character set", "选择语言/字符");
regGS("All languages", "所有语言");
regGS("You do not have the right to modify templates.", "");
regGS("Invalid template file $1", "");
?>
